%global momorel 3

%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

# Always set these 3 tags
%define base_version 3.3.1
%define base_release 11

# Hypervisor ABI
%define hv_abi  3.3
# Whether to build -hypervisor pacakges
%define hv_build 1

# For testing upstream dev trees run either
#    hg archive -t tgz ../xen-unstable-[changeset].tgz
# Or
#    hg archive -t tgz ../xen-3.1-testing-[changeset].tgz
#
# And set 'base_version' the release number that the current
# dev tree is targetted to become,

# For dev trees, also set the changeset synced to
#define changeset 16701

# Name of the tree (ie the arg to hg archive, without .tgz suffix)
#define tree unstable
#define tree 3.1-testing

# If upstream tree is also in release candidate stage, add this tag
#define relcandidate 5



# Don't change the following - they're all set based on the above params
#
# For prod RPMs we end up with a
#    xen-3.1.2-1.fc9.i686.rpm
#
# For dev RPMs we end up with a
#    xen-3.2.0-0.fc9.rc1.dev16606.i686.rpm
#
# NB, the leading '0' in the release ensures it is older than
# the first prod RPM for 3.2.0


%define release_prefix %{?changeset:0}%{!?changeset:%{base_release}}
%define release_postfix %{?changeset:%{?relcandidate:.rc%{relcandidate}}.dev%{changeset}.%{base_release}}
%define version_tag %{base_version}
%define release_tag %{release_prefix}%{?dist}%{release_postfix}
%define directory_tag xen-%{?changeset:%{tree}-%{changeset}}%{!?tree:%{base_version}}
%define source_tag %{directory_tag}.tar.gz


Summary: Xen is a virtual machine monitor
Name:    xen
Version: %{version_tag}
Release: %{momorel}m%{?dist}
Group:   Development/Libraries
License: GPLv2+ and LGPLv2+ and BSD
URL:     http://xen.org/
Source0: %{source_tag}
Source1: %{name}.modules
Source2: %{name}.logrotate
# used by stubdoms
Source10: lwip-1.3.0.tar.gz
Source11: newlib-1.16.0.tar.gz
Source12: zlib-1.2.3.tar.gz
Source13: pciutils-2.2.9.tar.bz2
Source14: grub-0.97.tar.gz
Patch1: xen-initscript.patch
Patch2: xen-initscript-pvops.patch
Patch3: xen-fix-deprecated-warnings.patch
Patch8: xen-xenstore-cli.patch
Patch13: xen-dumpdir.patch
Patch14: xen-net-disable-bridge-by-default.patch
Patch15: xen-net-disable-iptables-on-bridge.patch
Patch16: xen-gcc44-buildfix.patch
Patch17: xen-xenstored-fix.diff
Patch20: xen-backport-hg18782.patch
Patch21: xen-backport-hg19075.patch
Patch22: xen-backport-hg19108.patch
Patch23: xen-backport-hg19109.patch
Patch24: xen-backport-hg19110.patch
Patch30: xen-qemu-dm-unplug.diff


# Patches to modify the default config of xend
Patch100: xen-config-dom0-minmem.patch
Patch102: xen-3.0.2-config-allow-unix-server.patch
Patch103: xen-3.0.2-config-disable-reloc.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: transfig libidn-devel zlib-devel texi2html SDL-devel curl-devel
BuildRequires: libX11-devel python-devel ghostscript tetex-latex
BuildRequires: ncurses-devel gtk2-devel libaio-devel
# for the docs
BuildRequires: perl texinfo
# so that the makefile knows to install udev rules
BuildRequires: udev
%ifnarch ia64
# so that x86_64 builds pick up glibc32 correctly
BuildRequires: /usr/include/gnu/stubs-32.h
# for the VMX "bios"
BuildRequires: dev86
%endif
BuildRequires: gettext
BuildRequires: gnutls-devel
BuildRequires: openssl-devel
# For ioemu PCI passthrough
BuildRequires: pciutils-devel
Requires: bridge-utils
Requires: udev >= 059
Requires: xen-runtime = %{version}-%{release}
# Not strictly a dependency, but kpartx is by far the most useful tool right
# now for accessing domU data from within a dom0 so bring it in when the user
# installs xen.
Requires: kpartx
Prereq: chkconfig
ExclusiveArch: %{ix86} x86_64 ia64

%description
This package contains the XenD daemon and xm command line
tools, needed to manage virtual machines running under the
Xen hypervisor

%package libs
Summary: Libraries for Xen tools
Group: Development/Libraries
Requires(pre): /sbin/ldconfig
Requires(post): /sbin/ldconfig

%description libs
This package contains the libraries needed to run applications
which manage Xen virtual machines.


%package runtime
Summary: Core Xen runtime environment
Group: Development/Libraries
Requires: xen-libs = %{version}-%{release}
Requires: qemu
# Ensure we at least have a suitable kernel installed, though we can't
# force user to actually boot it.
Requires: xen-hypervisor-abi = %{hv_abi}

%description runtime
This package contains the runtime programs and daemons which
form the core Xen userspace environment.


%if %{hv_build}
%package hypervisor
Summary: Libraries for Xen tools
Group: Development/Libraries
Provides: xen-hypervisor-abi = %{hv_abi}

%description hypervisor
This package contains the Xen hypervisor
%endif

%package devel
Summary: Development libraries for Xen tools
Group: Development/Libraries
Requires: xen-libs = %{version}-%{release}

%description devel
This package contains what's needed to develop applications
which manage Xen virtual machines.

%prep
%setup -q -n %{directory_tag}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch8 -p1

%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1

%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1

cd tools/ioemu-qemu-xen
%patch30 -p1
cd ../../

# config patches
%patch100 -p1
%patch102 -p1
%patch103 -p1

# stubdom sources
cp -v %{SOURCE10} %{SOURCE11} %{SOURCE12} %{SOURCE13} %{SOURCE14} stubdom

%build
export XEN_VENDORVERSION="-%{release_tag}"
%if %{hv_build}
CFLAGS="$RPM_OPT_FLAGS" %{__make} XEN_PYTHON_NATIVE_INSTALL=1 DESTDIR=%{buildroot} tools docs xen
%{__make} stubdom
%else
CFLAGS="$RPM_OPT_FLAGS" %{__make} XEN_PYTHON_NATIVE_INSTALL=1 DESTDIR=%{buildroot} tools docs
%{__make} stubdom
%endif

%install
rm -rf %{buildroot}
make XENFB_TOOLS=y XEN_PYTHON_NATIVE_INSTALL=1 DESTDIR=%{buildroot} prefix=/usr install-tools install-docs install-stubdom
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/xend-db/domain
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/xend-db/vnet
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/xend-db/migrate
mkdir -p %{buildroot}%{_localstatedir}/lib/xenstored
mkdir -p %{buildroot}%{_localstatedir}/run/xenstored

rm -rf %{buildroot}%{_sysconfdir}/hotplug

# install all of the public headers
mkdir -p %{buildroot}%{_includedir}/xen/io %{buildroot}%{_includedir}/xen/hvm
mkdir -p %{buildroot}%{_includedir}/xen/arch-x86 %{buildroot}%{_includedir}/xen/xsm
install -m 644 xen/include/public/io/*.h %{buildroot}%{_includedir}/xen/io
install -m 644 xen/include/public/hvm/*.h %{buildroot}%{_includedir}/xen/hvm
install -m 644 xen/include/public/xsm/*.h %{buildroot}%{_includedir}/xen/xsm
install -m 644 xen/include/public/arch-x86/*.h %{buildroot}%{_includedir}/xen/arch-x86
install -m 644 xen/include/public/*.h %{buildroot}%{_includedir}/xen/

%if %{hv_build}
# install the hypervisor
install -d 755 %{buildroot}/boot/
install -m 644 xen/xen.gz %{buildroot}/boot/xen-%{hv_abi}.gz
install -m 644 xen/xen-syms %{buildroot}/boot/xen-syms-%{hv_abi}
%endif

mv -f %{buildroot}%{_sysconfdir}/udev/xen-backend.rules %{buildroot}%{_sysconfdir}/udev/rules.d/

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/modules
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/modules/%{name}.modules

mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# silly doc dir fun
rm -fr %{buildroot}%{_datadir}/doc/xen
rm -rf %{buildroot}%{_datadir}/doc/qemu

# Pointless wrapper
rm -f %{buildroot}%{_libdir}/%{name}/bin/qemu-dm.debug
# Pointless helper
rm -f %{buildroot}%{_sbindir}/xen-python-path
# Just plain evil
rm -f %{buildroot}%{_sbindir}/netfix

# Tools that upstream are dropping
# ...replaced by kpartx
rm -f %{buildroot}%{_bindir}/lomount
# ...replaced by any serial console program
rm -f %{buildroot}%{_bindir}/xencons

# Not built into our Xen kernels
rm -f %{buildroot}%{_bindir}/xenperf
rm -f %{buildroot}%{_sbindir}/xenperf

# Doesn't work
rm -f %{buildroot}%{_sbindir}/xsview

# create dirs in /var/run so that selinux contexts are right (#195952)
mkdir -p %{buildroot}%{_localstatedir}/run/xend
mkdir -p %{buildroot}%{_localstatedir}/run/xend/boot
mkdir -p %{buildroot}%{_localstatedir}/log/xen
mkdir -p %{buildroot}%{_localstatedir}/log/xen/console
mkdir -p %{buildroot}%{_localstatedir}/lib/xen/images

# avoid conflicting with qemu (#199759)
rm -f %{buildroot}/%{_mandir}/man*/qemu*

# Don't duplicate binary already provided in QEMU
rm -f %{buildroot}/%{_bindir}/qemu-img-xen
ln -s qemu-img %{buildroot}/%{_bindir}/qemu-img-xen

# Blow away clashing files
rm -f %{buildroot}/%{_datadir}/xen/man/man1/qemu.1*
rm -f %{buildroot}/%{_datadir}/xen/man/man1/qemu-img.1*

# blow away unused files
for i in bios.bin openbios-sparc32 openbios-sparc64 ppc_rom.bin \
         pxe-ne2k_pci.bin pxe-pcnet.bin pxe-rtl8139.bin \
         vgabios.bin vgabios-cirrus.bin video.x
do
  rm -f %{buildroot}/%{_datadir}/xen/qemu/$i
done

# blow away README's not intended for end users
rm -f %{buildroot}/%{_sysconfdir}/xen/README*

#find_lang xen-xm

%post
/sbin/chkconfig --add xend
/sbin/chkconfig --add xendomains

if [ $1 != 0 ]; then
  service xend condrestart
fi

%preun
if [ $1 = 0 ]; then
  /sbin/chkconfig --del xend
  /sbin/chkconfig --del xendomains
fi

%post runtime
/sbin/chkconfig --add xenconsoled
/sbin/chkconfig --add xenstored
#/sbin/chkconfig --add blktapctrl

if [ $1 != 0 ]; then
  service xenconsoled condrestart
fi

%preun runtime
if [ $1 = 0 ]; then
  /sbin/chkconfig --del xenconsoled
  /sbin/chkconfig --del xenstored
  /sbin/chkconfig --del blktapctrl
fi

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

# Base package only contains XenD/xm python stuff
#files -f xen-xm.lang
%files
%defattr(-,root,root)
%doc COPYING README
#doc docs/pdf/
%doc docs/misc/
%{_sbindir}/xend
%{_sbindir}/xm
# XenD / xm python code
%{python_sitearch}/%{name}
%{python_sitearch}/xen-*.egg-info
%{_mandir}/man1/xm.1*
%{_mandir}/man5/xend-config.sxp.5*
%{_mandir}/man5/xmdomain.cfg.5*

%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.dtd

# Startup script
%{_initscriptdir}/xend
%{_initscriptdir}/xendomains
# Guest config files
%config(noreplace) %{_sysconfdir}/%{name}/xmexample*
# Daemon config
%config(noreplace) %{_sysconfdir}/%{name}/xend-*
# xm config
%config(noreplace) %{_sysconfdir}/%{name}/xm-*
# Guest autostart links
%dir %attr(0700,root,root) %{_sysconfdir}/%{name}/auto
# Autostart of guests
%config(noreplace) %{_sysconfdir}/sysconfig/xendomains

# Persistent state for XenD
%dir %{_localstatedir}/lib/%{name}/xend-db/
%dir %{_localstatedir}/lib/%{name}/xend-db/domain
%dir %{_localstatedir}/lib/%{name}/xend-db/migrate
%dir %{_localstatedir}/lib/%{name}/xend-db/vnet

%files libs
%defattr(-,root,root)
%{_libdir}/*.so.*
%{_libdir}/fs/*


# All runtime stuff except for XenD/xm python stuff
%files runtime
%defattr(-,root,root)
# Hotplug rules
%config(noreplace) %{_sysconfdir}/udev/rules.d/*

%dir %attr(0700,root,root) %{_sysconfdir}/%{name}
%dir %attr(0700,root,root) %{_sysconfdir}/%{name}/scripts/
%config %attr(0700,root,root) %{_sysconfdir}/%{name}/scripts/*
%config %attr(0700,root,root) %{_sysconfdir}/%{name}/qemu-ifup

%{_initscriptdir}/blktapctrl
%{_initscriptdir}/xenstored
%{_initscriptdir}/xenconsoled

%config(noreplace) %{_sysconfdir}/sysconfig/xenstored
%config(noreplace) %{_sysconfdir}/sysconfig/xenconsoled
%config(noreplace) %{_sysconfdir}/sysconfig/blktapctrl

# Auto-load xen backend drivers
%attr(0755,root,root) %{_sysconfdir}/sysconfig/modules/%{name}.modules

# Rotate console log files
%config(noreplace) %{_sysconfdir}/logrotate.d/xen

# Programs run by other programs
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/bin
%attr(0700,root,root) %{_libdir}/%{name}/bin/*
# QEMU runtime files
%dir %{_datadir}/%{name}/qemu
%dir %{_datadir}/%{name}/qemu/keymaps
%{_datadir}/%{name}/qemu/keymaps/*

# man pages
%{_mandir}/man1/xentop.1*
%{_mandir}/man1/xentrace_format.1*
%{_mandir}/man8/xentrace.8*

%{python_sitearch}/fsimage.so
%{python_sitearch}/grub
%{python_sitearch}/pygrub-*.egg-info

# The firmware
%ifnarch ia64
# Avoid owning /usr/lib twice on i386
%if "%{_libdir}" != "/usr/lib"
%dir /usr/lib/%{name}
%endif
%dir /usr/lib/%{name}/bin
%dir /usr/lib/%{name}/boot
# HVM loader is always in /usr/lib regardless of multilib
/usr/lib/xen/bin/stubdom-dm
/usr/lib/xen/boot/ioemu-stubdom.gz
/usr/lib/xen/boot/hvmloader
/usr/lib/xen/boot/pv-grub*.gz
%endif
# General Xen state
%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/dump
%dir %{_localstatedir}/lib/%{name}/images
# Xenstore persistent state
%dir %{_localstatedir}/lib/xenstored
# Xenstore runtime state
%dir %{_localstatedir}/run/xenstored
# XenD runtime state
%dir %attr(0700,root,root) %{_localstatedir}/run/xend
%dir %attr(0700,root,root) %{_localstatedir}/run/xend/boot

# All xenstore CLI tools
%{_bindir}/qemu-img-xen
%{_bindir}/xenstore
%{_bindir}/xenstore-*
%{_bindir}/pygrub
%{_bindir}/xentrace*
# blktap daemon
%{_sbindir}/blktapctrl
%{_sbindir}/tapdisk
# XSM
%{_sbindir}/flask-loadpolicy
# Disk utils
%{_sbindir}/qcow-create
%{_sbindir}/qcow2raw
%{_sbindir}/img2qcow
# Misc stuff
%{_bindir}/xen-detect
%{_sbindir}/fs-backend
%{_sbindir}/xen-bugtool
%{_sbindir}/xenconsoled
%{_sbindir}/xenmon.py*
%{_sbindir}/xentop
%{_sbindir}/xentrace_setmask
%{_sbindir}/xenbaked
%{_sbindir}/xenstored
%{_sbindir}/xenpm

# Xen logfiles
%dir %attr(0700,root,root) %{_localstatedir}/log/xen
# Guest/HV console logs
%dir %attr(0700,root,root) %{_localstatedir}/log/xen/console

%if %{hv_build}
%files hypervisor
%defattr(-,root,root)
/boot/xen-syms-*
/boot/xen-*.gz
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/*.h
%dir %{_includedir}/xen
%{_includedir}/xen/*
%{_libdir}/*.so
%{_libdir}/*.a

%changelog
* Sun Jul 19 2009 Ryu SASAOKA <ryu@momonga-linux.org>
- (3.3.1-3m)
- stop daemon. modify Patch1

* Wed May 13 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.3.1-2m)
- modify Requires of xen-runtime
- move startup scripts from %%{_initrddir} to %%{_initscriptdir}

* Tue May 12 2009 Masahiro Takahata <takahata@momonga-linux.org>
- (3.3.1-1m)
- sync Fedora

* Tue Apr 07 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.2.0-16m)
- rebuild against openssl-0.9.8k

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.2.0-15m)
- rebuild against rpm-4.6

* Sun Jan 18 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.2.0-14m)
- [SECURITY] CVE-2008-0928
- import a security patch (Patch16) from Fedora 9 (3.2.0-15.fc9)

* Sat Jan 17 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.2.0-13m)
- [SECURITY] CVE-2008-1943 CVE-2008-1952 CVE-2008-1945 CVE-2008-2004
- import security patches from Fedora 9 (3.2.0-15.fc9)
-- Patch37 (CVE-2008-{1943,1952})
-- Patch38 (CVE-2008-{1945,2004})
- update Patch8 from Fedora 9 (3.2.0-15.fc9)
- update Patch3,13,102 for fuzz=0
- License: GPLv2+ and LGPLv2+ and Modified BSD

* Wed Dec 31 2008 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (3.2.0-12m)
- rebuild agaisst python-2.6.1-1m

* Tue Jul 15 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (3.2.0-11m)
- rebuild against gnutls-2.4.1

* Thu Jun  5 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (3.2.0-10m)
- rebuild against openssl-0.9.8h-1m

* Wed Apr 30 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.2.0-9m)
- restrict python ver-rel for egginfo

* Tue Apr 29 2008 Masahiro Takahata <takahata@momonga-linux.org>
- (3.2.0-8m)
- enable egg-info

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.2.0-7m)
- rebuild against gcc43

* Fri Feb 15 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.2.0-6m)
- adjust %%files for the newest python
- BR: python-devel >= 2.5.1-7m

* Mon Feb 11 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.2.0-5m)
- adjust %%files again for x86_64

* Fri Feb  8 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.2.0-4m)
- adjust %%files for new python
- BR: python-devel >= 2.5.1-5m

* Thu Feb  7 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.2.0-3m)
- fix files conflicts

* Sat Feb  2 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (3.2.0-2m)
- split xen-runtime

* Thu Jan 31 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (3.2.0-1m)
- [SECURITY] CVE-2007-5906 CVE-2007-5907
- update 3.2.0

* Mon Dec  3 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (3.1.2-1m)
- update 3.1.2

* Tue Oct 30 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (3.1.0-3m)
- cleanup spec
- fix CVE-2007-1321, CVE-2007-3919, CVE-2007-4993
-- import Fedora Patches(3.1.0-13)
 
* Mon Jul 23 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (3.1.0-2m)
- add Requires: initscripts
- fix %%post PATH to service
 
* Tue Jun 19 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (3.1.0-1m)
- up to 3.1.0
- be synchronized with fedora
- modify initscripts

* Fri Jun  8 2007 Masahiro Takahata <takahata@momonga-linux.org>
- (3.1.0-0.rc7.1m)
- sync Fedora

* Wed Mar 14 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0.3-4m)
- makimodosi 3.0.3-2

* Wed Mar 14 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0.3-3m)
- add export LDFLAGS="-L/%{_lib} $LDFLAGS"
-- Because /lib/libncurses.so cannot be linked

* Sat Dec 23 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0.3-2m)
- rebuild against python-2.5

* Mon Oct 06 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.0.3-1m)
- merge FC 3.0.3-1

* Fri Jul  7 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (3.0.2-1m)
- import from fc-devel

* Sun Jan  8 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (3.0-0.20051206.1m)
- sync with fc-devel

* Sat Oct 30 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2-20051030m)
- rebuild against python-2.4.2

* Wed Mar 23 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2-20050308m)
- import from FC

* Wed Mar  9 2005 Rik van Riel <riel@redhat.com> 2-20050308
- upgrade to last night's snapshot
- new compile fix patch

* Sun Mar  6 2005 Rik van Riel <riel@redhat.com> 2-20050305
- the gcc4 compile patches are now upstream
- upgrade to last night's snapshot, drop patches locally

* Fri Mar  4 2005 Rik van Riel <riel@redhat.com> 2-20050303
- finally got everything to compile with gcc4 -Wall -Werror

* Thu Mar  3 2005 Rik van Riel <riel@redhat.com> 2-20050303
- upgrade to last night's Xen-unstable snapshot
- drop printf warnings patch, which is upstream now

* Wed Feb 23 2005 Rik van Riel <riel@redhat.com> 2-20050222
- upgraded to last night's Xen snapshot
- compile warning fixes are now upstream, drop patch

* Sat Feb 19 2005 Rik van Riel <riel@redhat.com> 2-20050219
- fix more compile warnings
- fix the fwrite return check

* Fri Feb 18 2005 Rik van Riel <riel@redhat.com> 2-20050218
- upgrade to last night's Xen snapshot
- a kernel upgrade is needed to run this Xen, the hypervisor
  interface changed slightly
- comment out unused debugging function in plan9 domain builder
  that was giving compile errors with -Werror

* Tue Feb  8 2005 Rik van Riel <riel@redhat.com> 2-20050207
- upgrade to last night's Xen snapshot

* Tue Feb  1 2005 Rik van Riel <riel@redhat.com> 2-20050201.1
- move everything to /var/lib/xen

* Tue Feb  1 2005 Rik van Riel <riel@redhat.com> 2-20050201
- upgrade to new upstream Xen snapshot

* Tue Jan 25 2005 Jeremy Katz <katzj@redhat.com>
- add buildreqs on python-devel and xorg-x11-devel (strange AT nsk.no-ip.org)

* Mon Jan 24 2005 Rik van Riel <riel@redhat.com> - 2-20050124
- fix /etc/xen/scripts/network to not break with ipv6 (also sent upstream)

* Fri Jan 14 2005 Jeremy Katz <katzj@redhat.com> - 2-20050114
- update to new snap
- python-twisted is its own package now
- files are in /usr/lib/python now as well, ugh.

* Tue Jan 11 2005 Rik van Riel <riel@redhat.com>
- add segment fixup patch from xen tree
- fix %files list for python-twisted

* Mon Jan 10 2005 Rik van Riel <riel@redhat.com>
- grab newer snapshot, that does start up
- add /var/xen/xend-db/{domain,vnet} to %files section

* Thu Jan  6 2005 Rik van Riel <riel@redhat.com>
- upgrade to new snapshot of xen-unstable

* Mon Dec 13 2004 Rik van Riel <riel@redhat.com>
- build python-twisted as a subpackage
- update to latest upstream Xen snapshot

* Sun Dec  5 2004 Rik van Riel <riel@redhat.com>
- grab new Xen tarball (with wednesday's patch already included)
- transfig is a buildrequire, add it to the spec file

* Wed Dec  1 2004 Rik van Riel <riel@redhat.com>
- fix up Che's spec file a little bit
- create patch to build just Xen, not the kernels

* Wed Dec 01 2004 Che
- initial rpm release
